pub enum RegionMatch {
Uncompared,
Match {
seq_match: Arc<LibraryRegion>,
distance: u64,
diff: Option<SequenceDiff>,
},
MultiMatch {
seq_matches: Vec<Arc<LibraryRegion>>,
distance: u64,
diffs: Option<Vec<SequenceDiff>>,
},
Overmatched {
distance: u64,
matches: usize,
},
Unmatched,
NoLibrary {
seq: Option<SeqHandle>,
},
}Expand description
Status of the match between an ObservedRegion and a Library
This stores both the qualitative match status and any associated library sequence(s), distance(s), and sequence-difference information.
Variants
Uncompared
Library comparison has not yet been performed.
Match
A unique best library-region match was found.
MultiMatch
Multiple equally good best library-region matches were found.
Overmatched
More than max_matches equally good matches were found.
Unmatched
No acceptable library-region match was found.
NoLibrary
This region is not represented in the supplied library.
The observed sequence may optionally be retained for output.
Implementations
Sourceimpl RegionMatch
impl RegionMatch